# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V6::Enums::HotelPriceBucketEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED        => "UNSPECIFIED",
  UNKNOWN            => "UNKNOWN",
  LOWEST_UNIQUE      => "LOWEST_UNIQUE",
  LOWEST_TIED        => "LOWEST_TIED",
  NOT_LOWEST         => "NOT_LOWEST",
  ONLY_PARTNER_SHOWN => "ONLY_PARTNER_SHOWN"
];

1;
